/***************************************************************************
 *   Copyright (C) 2004 by Raphael Langerhorst                             *
 *   raphael-langerhorst@gmx.at                                            *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#ifndef GBEGENERGYFORMAGENT_H
#define GBEGENERGYFORMAGENT_H

#include <GAgent.h>

namespace GBE {

/**
  \class GEnergyFormAgent GEnergyFormAgent.h
  \brief Modifies the form according to the energy attributes.
  @author Raphael Langerhorst
  
  The form of the element is modified according to energy. The
  energy level is represented by form colour, the energy amount
  is represented by form radius. For this to work the element
  needs to have an energy and a GOpenGLForm.
  
  The colour ranges from dark blue to yellow-white between
  LevelRangeMin and LevelRangeMax.
  
  The energy amount is currently mapped 1:1 to the form radius.
  
  @todo add factor for energy amount to form radius mapping.
*/
class GEnergyFormAgent : public GCS::GAgent
{
  Q_OBJECT
  public:
    /**
     * Constructor.
     * @param level_range_min energy level for dark blue
     * @param level_range_max energy level for yellow-white
     */
    GEnergyFormAgent(double level_range_min = 0, double level_range_max = 10,
                     QObject* parent = 0, const char* name = 0);

    /**
     * Destructor.
     */
    virtual ~GEnergyFormAgent();
    
  protected:
  
    /**
     * The energy level at which (and below) the form colour is set
     * to dark blue.
     */
    double LevelRangeMin;
    
    /**
     * The energy level at which (and above) the form colour is set
     * to light yellow.
     */
    double LevelRangeMax;
  
    /**
     * Periodically updates the form of the element according to
     * the current energy.
     */
    virtual void run();
};

};

#endif
