/***************************************************************************
 *   Copyright (C) 2004 by Raphael Langerhorst                             *
 *   raphael-langerhorst@gmx.at                                            *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/
 
#ifndef GBEGOPENGLFORMH
#define GBEGOPENGLFORMH

#include <GForm.h>

#include <qgl.h>
#include <qcolor.h>

namespace GBE
{

/**
  \class GOpenGLForm GOpenGLForm.h
  \brief Implements a form that is usable with OpenGL.
  @author Raphael Langerhorst

  By default a sphere is drawn with its radius. This form is able to transform
  and render itself.

  You can use it by just calling transform() and render() in a valid OpenGL context.
  
  This class is intended as a base class for all forms that are OpenGL capable.
*/
class GOpenGLForm : public GCS::GForm
{

  public:

    /**
     * The radius of the form (by default a sphere).
     * @note diameter = 2 * Radius
     */
    double Radius;

    /**
     * The Red, Green, Blue and Alpha colour values of the form.
     */
    float RGBA[4];
    
  public:

    /**
     * Constructor with optional parameters.
     * @todo put the implementation into the implementation file.
     */
    GOpenGLForm(const GCS::GVector3& position = GCS::GVector3(0,0,0),
             const GCS::GVector3& rotation = GCS::GVector3(0,0,0),
             double radius = 1)
    : GCS::GForm(position,rotation),
      Radius(radius)
    {
      RGBA[0] = RGBA[1] = RGBA[2] = RGBA[3] = 0.5;
    }

    /**
     * Virtual destructor for clean subclassing.
     * @todo put the implementation into the implementation file.
     */
    virtual ~GOpenGLForm()
    {}
    
    //please make sure these are called in a valid OpenGL context!!
    
    /**
     * Transforms the current matrix according
     * to position, rotation and radius.
     */
    virtual void transform() const;
    
    /**
     * Renders the form, by default a sphere.
     */
    virtual void render() const;
    
    
    /**
     * Returns the Radius.
     * @todo put into implementation file.
     */
    virtual double getRadiusMax() const { return Radius; }
    
    /**
     * Returns the Radius.
     * @todo put into implementation file.
     */
    virtual double getRadiusMin() const { return Radius; }

};

};

#endif
