/***************************************************************************
 *   Copyright (C) 2004 by Raphael Langerhorst                             *
 *   raphael-langerhorst@gmx.at                                            *
 *                                                                         *
 *   Permission is hereby granted, free of charge, to any person obtaining *
 *   a copy of this software and associated documentation files (the       *
 *   "Software"), to deal in the Software without restriction, including   *
 *   without limitation the rights to use, copy, modify, merge, publish,   *
 *   distribute, sublicense, and/or sell copies of the Software, and to    *
 *   permit persons to whom the Software is furnished to do so, subject to *
 *   the following conditions:                                             *
 *                                                                         *
 *   The above copyright notice and this permission notice shall be        *
 *   included in all copies or substantial portions of the Software.       *
 *                                                                         *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,       *
 *   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF    *
 *   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*
 *   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR     *
 *   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, *
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR *
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/

#ifndef GBEGSOLARSYSTEMFORMH
#define GBEGSOLARSYSTEMFORMH

#include "GOpenGLForm.h"

namespace GBE {

/**
  \class GSolarSystemForm GSolarSystemForm.h
  \brief Simple representation of a solar system
  @author Raphael Langerhorst

  This class just changes the size of the drawn sphere to a
  fraction of the solar system size. Thus it is easily possible
  to create solar systems of a certain size which then already
  includes the sun.
  @note Many parts of the GBE are in a very primitive state and
  still are there for testing purposes; this form is probably another
  such class. Most classes of the GBE are expected to either
  change heavily or even be replaced by new classes.*/
class GSolarsystemForm : public GOpenGLForm
{
  private:
  
    /**
     * The fraction with which the radius is multiplied when rendering.
     * This is normally below 1 and determines the diameter of the sun
     * of one solar system compared to the diameter of the whole solar system.
     */
    double SolFraction;
  
  public:
    GSolarsystemForm(const GCS::GVector3& position, const GCS::GVector3& rotation, double radius, double sol_size_fraction = 0.05);

    virtual ~GSolarsystemForm();

    virtual void render() const;

};

};

#endif
